@@ -15,7 +15,6 @@ class Poll(ButtonMenu):
     Attributes
         :ctx: A reference to the command context.
         :timeout: How long (in seconds) before the poll ends.
-        :voted: Dictionary that tracks users who have already voted.
     """
 
     def __init__(self, ctx: Context, timeout: int = 300):
@@ -23,19 +22,17 @@ class Poll(ButtonMenu):
         self.voted: Set[User] = set()
 
     def __repr__(self):
-        return f'<Menu pages={[p.__str__() for p in self.pages]}, timeout={self.timeout}, active={self.active} page={self.page_index},' \
-               f'data={self.data}>'
+        return f'Poll(pages={[p.__str__() for p in self.pages]}, timeout={self.timeout}, active={self.active} page={self.page_index},' \
+               f'data={self.data})'
 
     async def open(self):
         """The entry point to a new TextMenu instance; starts the main menu loop.
         Manages gathering user input, basic validation, sending messages, and cancellation requests."""
         await self._validate_pages()
 
-        if not await super().validate_user():
+        if await self._start_session() is False:
             return
 
-        await super().set_user_active()
-
         await self._set_data()
 
         self.output = await self.ctx.send(embed=self.page)
@@ -83,7 +80,8 @@ class Poll(ButtonMenu):
         """Watches for a user adding a reaction on the Poll. Adds them to the relevant state_field values."""
         while True:
             try:
-                reaction, user = await self.ctx.bot.wait_for('reaction_add', timeout=self.timeout, check=lambda _, u: u != self.ctx.bot.user)
+                reaction, user = await self.ctx.bot.wait_for('reaction_add', timeout=self.timeout,
+                                                             check=lambda _, u: u != self.ctx.bot.user)
 
             except asyncio.TimeoutError:
                 return
@@ -96,7 +94,8 @@ class Poll(ButtonMenu):
         """Watches for a user removing a reaction on the Poll. Removes them from the relevant state_field values."""
         while True:
             try:
-                reaction, user = await self.ctx.bot.wait_for('reaction_remove', timeout=self.timeout, check=lambda _, u: u != self.ctx.bot.user)
+                reaction, user = await self.ctx.bot.wait_for('reaction_remove', timeout=self.timeout,
+                                                             check=lambda _, u: u != self.ctx.bot.user)
 
             except asyncio.TimeoutError:
                 return
